@@ -17,9 +17,9 @@
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
-#include <ntqstring.h>
-#include <ntqapplication.h>
-#include <ntqregexp.h>
+#include <tqstring.h>
+#include <tqapplication.h>
+#include <tqregexp.h>
 
 #include "encoderlatex.h"
 
