@@ -34,7 +34,7 @@ namespace KBibTeX
     */
     class EntryWidgetAuthor : public EntryWidgetTab
     {
-        Q_OBJECT
+        TQ_OBJECT
     public:
         EntryWidgetAuthor( BibTeX::File *bibtexfile, bool isReadOnly, TQWidget *parent = 0, const char *name = 0 );
         ~EntryWidgetAuthor();
