@@ -48,7 +48,7 @@ namespace KBibTeX
     */
     class EntryWidgetKeyword : public EntryWidgetTab
     {
-        Q_OBJECT
+        TQ_OBJECT
     public:
         EntryWidgetKeyword( BibTeX::File *bibtexfile, bool isReadOnly, TQWidget *parent = 0, const char *name = 0 );
         ~EntryWidgetKeyword();
