@@ -28,7 +28,7 @@ namespace KBibTeX
 
     class EntryWidgetMisc : public EntryWidgetTab
     {
-        Q_OBJECT
+        TQ_OBJECT
     public:
         EntryWidgetMisc( BibTeX::File *bibtexfile, bool isReadOnly, TQWidget *parent = 0, const char *name = 0 );
         ~EntryWidgetMisc();
