@@ -255,7 +255,7 @@ namespace KBibTeX
 
     void EntryWidgetPublication::updateWarnings( BibTeX::Entry::EntryType entryType, TQListView *listViewWarnings )
     {
-        bool crossRefValid = FALSE;
+        bool crossRefValid = false;
         BibTeX::Value *value = NULL;
 
         addMissingWarning( entryType, BibTeX::EntryField::ftHowPublished, m_fieldLineEditHowPublished->caption(), !m_fieldLineEditHowPublished->isEmpty(), m_fieldLineEditHowPublished, listViewWarnings );
