@@ -154,7 +154,7 @@ namespace KBibTeX
 
         KPushButton *btnReset = new KPushButton( i18n( "Restore" ), this );
         gridLayout->addWidget( btnReset, 1, 1 );
-        connect( btnReset, SIGNAL( clicked() ), this, SLOT( restore() ) );
+        connect( btnReset, TQ_SIGNAL( clicked() ), this, TQ_SLOT( restore() ) );
     }
 
 }
