@@ -33,7 +33,7 @@ namespace KBibTeX
 
     class EntryWidgetTab : public TQWidget
     {
-        Q_OBJECT
+        TQ_OBJECT
     public:
         EntryWidgetTab( BibTeX::File *bibtexfile, bool isReadOnly, TQWidget *parent = 0, const char *name = 0 );
         ~EntryWidgetTab();
