@@ -28,7 +28,7 @@ namespace KBibTeX
 
     class EntryWidgetTitle : public EntryWidgetTab
     {
-        Q_OBJECT
+        TQ_OBJECT
     public:
         EntryWidgetTitle( BibTeX::File *bibtexfile, bool isReadOnly, TQWidget *parent = 0, const char *name = 0 );
         ~EntryWidgetTitle();
