@@ -39,7 +39,7 @@ namespace KBibTeX
     */
     class FieldListView : public TQWidget
     {
-        Q_OBJECT
+        TQ_OBJECT
     public:
         FieldListView( const TQString& caption, const TQString& prefixNew, bool isReadOnly, TQWidget *parent = 0, const char *name = 0 );
         ~FieldListView();
