@@ -34,7 +34,7 @@ namespace BibTeX
     */
     class FileExporterBibUtils : public FileExporter
     {
-         Q_OBJECT
+         TQ_OBJECT
    public:
         FileExporterBibUtils( BibTeX::File::FileFormat outputFormat );
         ~FileExporterBibUtils();
