@@ -46,7 +46,7 @@ namespace BibTeX
     bool FileExporterPDF::save( TQIODevice* iodevice, const File* bibtexfile, TQStringList *errorLog )
     {
         m_mutex.lock();
-        bool result = FALSE;
+        bool result = false;
         m_embeddedFileList.clear();
         if ( m_embedFiles )
         {
@@ -73,7 +73,7 @@ namespace BibTeX
     bool FileExporterPDF::save( TQIODevice* iodevice, const Element* element, TQStringList *errorLog )
     {
         m_mutex.lock();
-        bool result = FALSE;
+        bool result = false;
         m_embeddedFileList.clear();
         if ( m_embedFiles )
             fillEmbeddedFileList( element );
@@ -114,9 +114,9 @@ namespace BibTeX
         TQStringList cmdLines = TQStringList::split( '|', "pdflatex -halt-on-error bibtex-to-pdf.tex|bibtex bibtex-to-pdf|pdflatex -halt-on-error bibtex-to-pdf.tex|pdflatex -halt-on-error bibtex-to-pdf.tex" );
 
         if ( writeLatexFile( laTeXFilename ) && runProcesses( cmdLines, errorLog ) && writeFileToIODevice( outputFilename, iodevice ) )
-            return TRUE;
+            return true;
         else
-            return FALSE;
+            return false;
     }
 
     bool FileExporterPDF::writeLatexFile( const TQString &filename )
@@ -156,10 +156,10 @@ namespace BibTeX
             ts << "\\bibliography{bibtex-to-pdf}\n";
             ts << "\\end{document}\n";
             latexFile.close();
-            return TRUE;
+            return true;
         }
         else
-            return FALSE;
+            return false;
     }
 
     void FileExporterPDF::fillEmbeddedFileList( const File* bibtexfile )
