@@ -39,7 +39,7 @@ namespace BibTeX
     bool FileExporterRIS::save( TQIODevice* iodevice, const Element* element, TQStringList* /*errorLog*/ )
     {
         m_mutex.lock();
-        bool result = FALSE;
+        bool result = false;
         TQTextStream stream( iodevice );
 
         const Entry *entry = dynamic_cast<const Entry*>( element );
@@ -53,8 +53,8 @@ namespace BibTeX
     bool FileExporterRIS::save( TQIODevice* iodevice, const File* bibtexfile, TQStringList* /*errorLog*/ )
     {
         m_mutex.lock();
-        bool result = TRUE;
-        m_cancelFlag = FALSE;
+        bool result = true;
+        m_cancelFlag = false;
         TQTextStream stream( iodevice );
 
         int numElements = (int) bibtexfile->count(), i = 0;
@@ -77,12 +77,12 @@ namespace BibTeX
 
     void FileExporterRIS::cancel()
     {
-        m_cancelFlag = TRUE;
+        m_cancelFlag = true;
     }
 
     bool FileExporterRIS::writeEntry( TQTextStream &stream, const Entry* entry )
     {
-        bool result = TRUE;
+        bool result = true;
         tqDebug( "Writing Entry" );
 
         switch ( entry->entryType() )
@@ -120,13 +120,13 @@ namespace BibTeX
                 result &= writeKeyValue( stream, field->fieldTypeName().right( 2 ), field->value()->simplifiedText() );
             else if ( field->fieldType() == EntryField::ftAuthor )
             {
-                TQStringList authors = TQStringList::split( TQRegExp( "\\s+(,|and|&)\\s+", FALSE ), field->value() ->simplifiedText() );
+                TQStringList authors = TQStringList::split( TQRegExp( "\\s+(,|and|&)\\s+", false ), field->value() ->simplifiedText() );
                 for ( TQStringList::Iterator it = authors.begin(); result && it != authors.end(); ++it )
                     result &= writeKeyValue( stream, "AU", *it );
             }
             else if ( field->fieldType() == EntryField::ftEditor )
             {
-                TQStringList authors = TQStringList::split( TQRegExp( "\\s+(,|and|&)\\s+", FALSE ), field->value() ->simplifiedText() );
+                TQStringList authors = TQStringList::split( TQRegExp( "\\s+(,|and|&)\\s+", false ), field->value() ->simplifiedText() );
                 for ( TQStringList::Iterator it = authors.begin(); result && it != authors.end(); ++it )
                     result &= writeKeyValue( stream, "ED", *it );
             }
@@ -194,7 +194,7 @@ namespace BibTeX
         stream << endl;
         tqDebug( "%s  - %s", key.latin1(), value.latin1() );
 
-        return TRUE;
+        return true;
     }
 
 }
