@@ -59,11 +59,11 @@ namespace BibTeX
             htmlTS.setEncoding( TQTextStream::UnicodeUTF8 );
             htmlTS << html << endl;
             m_mutex.unlock();
-            return TRUE;
+            return true;
         }
 
         m_mutex.unlock();
-        return FALSE;
+        return false;
     }
 
     bool FileExporterXSLT::save( TQIODevice* iodevice, const Element* element, TQStringList *errorLog )
@@ -85,11 +85,11 @@ namespace BibTeX
             output.setEncoding( TQTextStream::UnicodeUTF8 );
             output << html << endl;
             m_mutex.unlock();
-            return TRUE;
+            return true;
         }
 
         m_mutex.unlock();
-        return FALSE;
+        return false;
     }
 
 }
