@@ -413,7 +413,7 @@ namespace KBibTeX
             return -1; /** no value item found or is empty */
 
         /** parse value item's text */
-        bool ok = FALSE;
+        bool ok = false;
         int year = TQString( valueItem->text() ).toInt( &ok );
         if ( !ok ) year = -1;
 
