@@ -34,7 +34,7 @@ namespace KBibTeX
 {
     class IdSuggestionComponent: public TQFrame
     {
-        Q_OBJECT
+        TQ_OBJECT
     public:
         IdSuggestionComponent( const TQString& title, TQWidget *parent );
         virtual TQString text() const = 0;
@@ -105,7 +105,7 @@ namespace KBibTeX
 
     class IdSuggestionsScrollView : public TQScrollView
     {
-        Q_OBJECT
+        TQ_OBJECT
     public:
         IdSuggestionsScrollView( TQWidget *parent, const char*name = NULL );
         ~IdSuggestionsScrollView();
@@ -124,7 +124,7 @@ namespace KBibTeX
     */
     class IdSuggestionsWidget : public TQWidget
     {
-        Q_OBJECT
+        TQ_OBJECT
     public:
         ~IdSuggestionsWidget();
         int numComponents();
