@@ -115,21 +115,21 @@ bool KBibTeXShell::openURL( const KURL& url )
     if ( m_part->url().isEmpty() && !m_part->isModified() )
     {
         if ( !m_part->openURL( url ) )
-            return FALSE;
+            return false;
     }
     else
     {
         KBibTeXShell *shell = new KBibTeXShell();
 
         if ( !shell->part() ->openURL( url ) )
-            return FALSE;
+            return false;
         else
             initializePart( shell->part() );
         shell->show();
     }
 
     m_recentFiles->addURL( url );
-    return TRUE;
+    return true;
 }
 
 KParts::ReadWritePart * KBibTeXShell::part()
@@ -281,7 +281,7 @@ void KBibTeXShell::applyNewToolbarConfig()
 bool KBibTeXShell::queryClose()
 {
     if ( m_part && !m_part ->closeURL() )
-        return FALSE;
+        return false;
 
     writeConfig();
 
@@ -326,7 +326,7 @@ void KBibTeXShell::slotFileOpen( const KURL& url )
 {
     if ( url.isEmpty() ) return ;
 
-    if ( !TDEIO::NetAccess::exists( url, TRUE, this ) )
+    if ( !TDEIO::NetAccess::exists( url, true, this ) )
     {
         m_recentFiles->removeURL( url );
         KMessageBox::error( this, i18n( "The given file could not be read, check if it exists or if it is readable for the current user." ) );
