@@ -36,7 +36,7 @@ namespace KBibTeX
 {
     TQDialog::DialogCode MacroWidget::execute( BibTeX::Macro *macro, bool isReadOnly, TQWidget *parent, const char *name )
     {
-        KDialogBase * dlg = new KDialogBase( parent, name, TRUE, i18n( "Edit BibTeX Macro" ), KDialogBase::Ok | KDialogBase::Cancel );
+        KDialogBase * dlg = new KDialogBase( parent, name, true, i18n( "Edit BibTeX Macro" ), KDialogBase::Ok | KDialogBase::Cancel );
         MacroWidget* macroWidget = new MacroWidget( macro, isReadOnly, dlg, "MacroWidget" );
 
         dlg->setMainWidget( macroWidget );
