@@ -761,11 +761,11 @@ namespace KBibTeX
     {
         MergeElementsCliqueItem *meci = dynamic_cast<MergeElementsCliqueItem*>( item );
         if ( meci != NULL && meci->entry != NULL )
-            KBibTeX::EntryWidget::execute( meci->entry, NULL, TRUE, FALSE, this );
+            KBibTeX::EntryWidget::execute( meci->entry, NULL, true, false, this );
         else if ( meci != NULL && meci->macro != NULL )
-            KBibTeX::MacroWidget::execute( meci->macro, TRUE, this );
+            KBibTeX::MacroWidget::execute( meci->macro, true, this );
         else if ( meci!=NULL&& meci->preamble!=NULL )
-            KBibTeX::PreambleWidget::execute( meci->preamble, TRUE, this );
+            KBibTeX::PreambleWidget::execute( meci->preamble, true, this );
     }
 
     /* This function was taken form TDEMainWindow of KDE 3.5 and modified to fit KBibTeX */
