@@ -30,7 +30,7 @@ namespace KBibTeX
 
     TQDialog::DialogCode PreambleWidget::execute( BibTeX::Preamble *preamble, bool isReadOnly, TQWidget *parent, const char *name )
     {
-        KDialogBase * dlg = new KDialogBase( parent, name, TRUE, i18n( "Edit BibTeX Preamble" ), KDialogBase::Ok | KDialogBase::Cancel );
+        KDialogBase * dlg = new KDialogBase( parent, name, true, i18n( "Edit BibTeX Preamble" ), KDialogBase::Ok | KDialogBase::Cancel );
         PreambleWidget* preambleWidget = new PreambleWidget( preamble, isReadOnly, dlg, "PreambleWidget" );
 
         dlg->setMainWidget( preambleWidget );
