@@ -17,28 +17,28 @@
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
-#include <ntqstring.h>
-#include <ntqprocess.h>
-#include <ntqstringlist.h>
-#include <ntqfont.h>
-#include <ntqregexp.h>
-#include <ntqwaitcondition.h>
-#include <ntqprocess.h>
-#include <ntqapplication.h>
+#include <tqstring.h>
+#include <tqprocess.h>
+#include <tqstringlist.h>
+#include <tqfont.h>
+#include <tqregexp.h>
+#include <tqwaitcondition.h>
+#include <tqprocess.h>
+#include <tqapplication.h>
 
 #include <tdeconfig.h>
 #include <kstandarddirs.h>
 #include <tdemessagebox.h>
 #include <tdelocale.h>
-#include <kbibtex_part.h>
 #include <kdebug.h>
 #include <tdeio/netaccess.h>
 
-#include <entryfield.h>
-#include <element.h>
-#include <entry.h>
-#include <macro.h>
+#include "entryfield.h"
+#include "element.h"
+#include "entry.h"
+#include "macro.h"
 #include "settings.h"
+#include "kbibtex_part.h"
 
 namespace KBibTeX
 {
@@ -61,10 +61,10 @@ namespace KBibTeX
         for ( int i = 0; i < numCompletions; ++i )
         {
             m_completion[ i ] = new TDECompletion();
-            m_completion[ i ] ->setIgnoreCase( TRUE );
+            m_completion[ i ] ->setIgnoreCase( true );
         }
         completionMacro = new TDECompletion();
-        completionMacro->setIgnoreCase( FALSE );
+        completionMacro->setIgnoreCase( false );
 
         currentBibTeXFile = NULL;
     }
@@ -99,9 +99,9 @@ namespace KBibTeX
         fileIO_BibtexStringOpenDelimiter = config->readEntry( "BibtexStringOpenDelimiter", "\"" ).at( 0 );
         fileIO_BibtexStringCloseDelimiter = config->readEntry( "BibtexStringCloseDelimiter", "\"" ).at( 0 );
         fileIO_KeywordCasing = ( BibTeX::FileExporterBibTeX::KeywordCasing ) config->readNumEntry( "KeywordCasing", ( int ) BibTeX::FileExporterBibTeX::kcCamelCase );
-        fileIO_EmbedFiles = config->readBoolEntry( "EmbedFiles", FALSE );
-        fileIO_EnclosingCurlyBrackets = config->readBoolEntry( "EnclosingCurlyBrackets", FALSE );
-        fileIO_useBibUtils = config->readBoolEntry( "UseBibUtils", TRUE );
+        fileIO_EmbedFiles = config->readBoolEntry( "EmbedFiles", false );
+        fileIO_EnclosingCurlyBrackets = config->readBoolEntry( "EnclosingCurlyBrackets", false );
+        fileIO_useBibUtils = config->readBoolEntry( "UseBibUtils", true );
         updateBib2Db5ClassPath( config->readEntry( "Bib2Db5BasePath", TQString::null ) );
         fileIO_NumberOfBackups = config->readNumEntry( "NumberOfBackups", 0 );
 
@@ -114,14 +114,14 @@ namespace KBibTeX
         editing_MainListColumnsWidth = config->readIntListEntry( "MainListColumnsWidth" );
         editing_MainListColumnsIndex = config->readIntListEntry( "MainListColumnsIndex" );
         editing_FilterHistory = config->readListEntry( "FilterHistory" );
-        editing_ShowComments = config->readBoolEntry( "ShowComments", TRUE );
-        editing_ShowMacros = config->readBoolEntry( "ShowMacros", TRUE );
+        editing_ShowComments = config->readBoolEntry( "ShowComments", true );
+        editing_ShowMacros = config->readBoolEntry( "ShowMacros", true );
         editing_HorSplitterSizes = config->readIntListEntry( "HorizontalSplitterSizes" );
         editing_VertSplitterSizes = config->readIntListEntry( "VerticalSplitterSizes" );
         TQFont defaultFont = TDEGlobalSettings::generalFont();
         editing_SpecialFont = config->readFontEntry( "SpecialFont", &defaultFont );
-        editing_UseSpecialFont = config->readBoolEntry( "UseSpecialFont", FALSE );
-        editing_FirstNameFirst = config->readBoolEntry( "FirstNameFirst", FALSE );
+        editing_UseSpecialFont = config->readBoolEntry( "UseSpecialFont", false );
+        editing_FirstNameFirst = config->readBoolEntry( "FirstNameFirst", false );
         editing_DocumentSearchPaths = config->readListEntry( "DocumentSearchPath" );
         editing_DragAction = ( DragAction ) config->readNumEntry( "DragAction", ( int ) COPYREFERENCE );
 
@@ -155,7 +155,7 @@ namespace KBibTeX
         {
             TQString descr = config->readEntry( TQString( "SearchURLDescription%1" ).arg( i ), TQString::null );
             TQString url = config->readEntry( TQString( "SearchURL%1" ).arg( i ), TQString::null );
-            bool includeAuthor = config->readBoolEntry( TQString( "IncludeAuthor%1" ).arg( i ), FALSE );
+            bool includeAuthor = config->readBoolEntry( TQString( "IncludeAuthor%1" ).arg( i ), false );
             if ( descr != TQString::null && url != TQString::null )
             {
                 SearchURL * searchURL = new SearchURL;
@@ -179,7 +179,7 @@ namespace KBibTeX
         webQuery_LastEngine = config->readNumEntry( "LastEngine", 0 );
         webQuery_LastSearchTerm = config->readEntry( "LastSearchTerm", "" );
         webQuery_LastNumberOfResults = config->readNumEntry( "LastNumberOfResults", 10 );
-        webQuery_ImportAll = config->readBoolEntry( "ImportAll", FALSE );
+        webQuery_ImportAll = config->readBoolEntry( "ImportAll", false );
 
         config->setGroup( "IdSuggestions" );
         idSuggestions_formatStrList = config->readListEntry( "FormatStrList" );
@@ -187,12 +187,12 @@ namespace KBibTeX
         {
             idSuggestions_formatStrList = TQStringList::split( ',', "A,A2|y,A3|y,A4|y|\":|T5,al|\":|T,al|y,al|Y,Al\"-|\"-|y,Al\"+|Y,al|y|T,al|Y|T3,al|Y|T3l,a|\":|Y|\":|T1,a|y,A|\":|Y" );
             idSuggestions_default = -1;
-            idSuggestions_forceDefault = FALSE;
+            idSuggestions_forceDefault = false;
         }
         else
         {
             idSuggestions_default = config->readNumEntry( "Default", -1 );
-            idSuggestions_forceDefault = config->readBoolEntry( "ForceDefault", FALSE );
+            idSuggestions_forceDefault = config->readBoolEntry( "ForceDefault", false );
         }
         idSuggestions_smallWords = config->readListEntry( "SmallWords" );
         if ( idSuggestions_smallWords.count() == 0 )
@@ -373,7 +373,7 @@ namespace KBibTeX
                 while ( result.isNull() && !input.atEnd() )
                 {
                     TQString line = input.readLine();
-                    if ( line.startsWith( "\\serverpipe ", FALSE ) )
+                    if ( line.startsWith( "\\serverpipe ", false ) )
                     {
                         TQStringList cols = TQStringList::split( TQRegExp( "\\s+\"|\"" ), line );
                         if ( cols.size() >= 2 )
@@ -465,8 +465,8 @@ namespace KBibTeX
                 if ( personContainer != NULL )
                     for ( TQValueList<BibTeX::Person*>::Iterator itp = personContainer->persons.begin();itp != personContainer->persons.end(); ++itp )
                     {
-                        m_completion[ index ] ->addItem(( *itp )->text( TRUE ) );
-                        m_completion[ index ] ->addItem(( *itp )->text( FALSE ) );
+                        m_completion[ index ] ->addItem(( *itp )->text( true ) );
+                        m_completion[ index ] ->addItem(( *itp )->text( false ) );
                     }
                 else
                 {
@@ -531,91 +531,91 @@ namespace KBibTeX
         SearchURL *searchURL = new SearchURL;
         searchURL->description = "Google";
         searchURL->url = "http://www.google.com/search?q=%1&ie=UTF-8&oe=UTF-8";
-        searchURL->includeAuthor = TRUE;
+        searchURL->includeAuthor = true;
         searchURLs.append( searchURL );
 
         searchURL = new SearchURL;
         searchURL->description = "Google Scholar";
         searchURL->url = "http://scholar.google.com/scholar?q=%1&ie=UTF-8&oe=UTF-8";
-        searchURL->includeAuthor = TRUE;
+        searchURL->includeAuthor = true;
         searchURLs.append( searchURL );
 
         searchURL = new SearchURL;
         searchURL->description = "Google .bib Search";
         searchURL->url = "http://www.google.com/search?q=%1%20filetype%3Abib&ie=UTF-8&oe=UTF-8";
-        searchURL->includeAuthor = TRUE;
+        searchURL->includeAuthor = true;
         searchURLs.append( searchURL );
 
         searchURL = new SearchURL;
         searchURL->description = "Google Document Search";
         searchURL->url = "http://www.google.com/search?q=%1%20filetype%3Apdf%20OR%20filetype%3Aps&ie=UTF-8&oe=UTF-8";
-        searchURL->includeAuthor = TRUE;
+        searchURL->includeAuthor = true;
         searchURLs.append( searchURL );
 
         searchURL = new SearchURL;
         searchURL->description = "PubMed";
         searchURL->url = "http://www.ncbi.nlm.nih.gov/entrez/query.fcgi?db=pubmed&cmd=search&pmfilter_Fulltext=on&pmfilter_Relevance=on&term=%1&search=Find+Articles";
-        searchURL->includeAuthor = FALSE;
+        searchURL->includeAuthor = false;
         searchURLs.append( searchURL );
 
         searchURL = new SearchURL;
         searchURL->description = "PubMed Central";
         searchURL->url = "http://www.ncbi.nlm.nih.gov/entrez/query.fcgi?db=pubmed&cmd=search&term=%1";
-        searchURL->includeAuthor = FALSE;
+        searchURL->includeAuthor = false;
         searchURLs.append( searchURL );
 
         searchURL = new SearchURL;
         searchURL->description = "Amatex (US)";
         searchURL->url = "http://www.2ndminute.org:8080/amatex/search.do?querry=%1&suchart=kwd&lang=DE";
-        searchURL->includeAuthor = FALSE;
+        searchURL->includeAuthor = false;
         searchURLs.append( searchURL );
 
         searchURL = new SearchURL;
         searchURL->description = "DBLP (Computer Science)";
         searchURL->url = "http://www.informatik.uni-trier.de/ley/dbbin/dblpquery.cgi?title=%1";
-        searchURL->includeAuthor = FALSE;
+        searchURL->includeAuthor = false;
         searchURLs.append( searchURL );
 
         searchURL = new SearchURL;
         searchURL->description = "CiteSeer";
         searchURL->url = "http://citeseer.ist.psu.edu/cis?q=%1&submit=Search+Documents";
-        searchURL->includeAuthor = FALSE;
+        searchURL->includeAuthor = false;
         searchURLs.append( searchURL );
 
         searchURL = new SearchURL;
         searchURL->description = "citebase";
         searchURL->url = "http://www.citebase.org/search?type=metadata&author=&title=%1&publication=&yearfrom=&yearuntil=&order=DESC&rank=paperimpact&submitted=Search";
-        searchURL->includeAuthor = FALSE;
+        searchURL->includeAuthor = false;
         searchURLs.append( searchURL );
 
         searchURL = new SearchURL;
         searchURL->description = "BASE";
         searchURL->url = "http://digital.ub.uni-bielefeld.de/index.php?q=%1&s=free";
-        searchURL->includeAuthor = FALSE;
+        searchURL->includeAuthor = false;
         searchURLs.append( searchURL );
 
         searchURL = new SearchURL;
         searchURL->description = "Forschungsportal.Net";
         searchURL->url = "http://www.forschungsportal.net/fpj/q/?q=%1&pp=5&art=dok&html=1&pdf=1&ps=1&dvi=1";
-        searchURL->includeAuthor = FALSE;
+        searchURL->includeAuthor = false;
         searchURLs.append( searchURL );
 
         searchURL = new SearchURL;
         searchURL->description = "scirus";
         searchURL->url = "http://www.scirus.com/srsapp/search?q=%1&ds=jnl&ds=nom&ds=web&g=s&t=all";
-        searchURL->includeAuthor = FALSE;
+        searchURL->includeAuthor = false;
         searchURLs.append( searchURL );
 
         searchURL = new SearchURL;
         searchURL->description = "ScientificCommons";
         searchURL->url = "http://en.scientificcommons.org/#search_string=%1";
-        searchURL->includeAuthor = FALSE;
+        searchURL->includeAuthor = false;
         searchURLs.append( searchURL );
 
         searchURL = new SearchURL;
         searchURL->description = "SpringerLink";
         searchURL->url = "http://www.springerlink.com/content/?k=%1";
-        searchURL->includeAuthor = FALSE;
+        searchURL->includeAuthor = false;
         searchURLs.append( searchURL );
     }
 
@@ -746,7 +746,7 @@ namespace KBibTeX
 
     bool Settings::kpsewhich( const TQString& filename )
     {
-        bool result = FALSE;
+        bool result = false;
         int counter = 0;
 
         TQWaitCondition waitCond;
@@ -779,14 +779,14 @@ namespace KBibTeX
         if ( _filename.contains( "~/" ) && !userHome.isEmpty() ) _filename = _filename.replace( "~/", userHome.append( "/" ) );
 
         KURL url( _filename );
-        if ( url.isValid() && ( !url.isLocalFile() || TDEIO::NetAccess::exists( url, TRUE, window ) ) )
+        if ( url.isValid() && ( !url.isLocalFile() || TDEIO::NetAccess::exists( url, true, window ) ) )
             return url;
 
         if ( bibTeXFileName != TQString::null )
         {
-            TQString path = KURL( bibTeXFileName ).directory( FALSE, FALSE );
+            TQString path = KURL( bibTeXFileName ).directory( false, false );
             url = KURL( path + "/" + _filename );
-            if ( url.isValid() && TDEIO::NetAccess::exists( url, TRUE, window ) )
+            if ( url.isValid() && TDEIO::NetAccess::exists( url, true, window ) )
                 return url;
         }
 
@@ -794,7 +794,7 @@ namespace KBibTeX
         for ( TQStringList::Iterator it = settings->editing_DocumentSearchPaths.begin(); it != settings->editing_DocumentSearchPaths.end(); ++it )
         {
             url = KURL( *it + "/" + _filename );
-            if ( url.isValid() && TDEIO::NetAccess::exists( url, TRUE, window ) )
+            if ( url.isValid() && TDEIO::NetAccess::exists( url, true, window ) )
                 return url;
         }
 
@@ -811,7 +811,7 @@ namespace KBibTeX
         if ( linkFilename[0] == '/' )
             return linkFilename;
         TQFileInfo fiO( originalFilename );
-        TQFileInfo fiL( fiO.dirPath( TRUE ) + "/" + linkFilename );
+        TQFileInfo fiL( fiO.dirPath( true ) + "/" + linkFilename );
         return fiL.absFilePath();
     }
 
