@@ -46,13 +46,13 @@ namespace KBibTeX
     IdSuggestionsListViewItem::IdSuggestionsListViewItem( TDEListView *list, const TQString& plainText, BibTeX::Entry *example ): TDEListViewItem( list ), m_original( plainText ), m_example( example )
     {
         TDEListViewItem::setText( 0, parse( plainText ) );
-        TDEListViewItem::setMultiLinesEnabled( TRUE );
+        TDEListViewItem::setMultiLinesEnabled( true );
     }
 
     IdSuggestionsListViewItem::IdSuggestionsListViewItem( TDEListView *list, TDEListViewItem *prev, const TQString& plainText, BibTeX::Entry *example ): TDEListViewItem( list, prev ), m_original( plainText ), m_example( example )
     {
         TDEListViewItem::setText( 0, parse( plainText ) );
-        TDEListViewItem::setMultiLinesEnabled( TRUE );
+        TDEListViewItem::setMultiLinesEnabled( true );
     }
 
     void IdSuggestionsListViewItem::setText( int col, const TQString& text )
@@ -170,7 +170,7 @@ namespace KBibTeX
     {
         IdSuggestionsListViewItem * item = new IdSuggestionsListViewItem( m_listIdSuggestions, "a|Y|T", m_example );
         item->setPixmap( 0, SmallIcon( "filter" ) );
-        m_listIdSuggestions->setSelected( item, TRUE );
+        m_listIdSuggestions->setSelected( item, true );
         TQTimer::singleShot( 100, this, TQ_SLOT( slotEditIdSuggestion() ) );
     }
 
@@ -333,9 +333,9 @@ namespace KBibTeX
         gridLayout->setColStretch( 0, 1 );
 
         m_listIdSuggestions = new TDEListView( this );
-        m_listIdSuggestions->setSorting( -1, FALSE );
+        m_listIdSuggestions->setSorting( -1, false );
         m_listIdSuggestions->addColumn( i18n( "Id Suggestions" ) );
-        m_listIdSuggestions->header()->setClickEnabled( FALSE );
+        m_listIdSuggestions->header()->setClickEnabled( false );
         m_listIdSuggestions->setFullWidth( true );
         gridLayout->addMultiCellWidget( m_listIdSuggestions, 0, 6, 0, 0 );
         connect( m_listIdSuggestions, TQ_SIGNAL( selectionChanged() ), this, TQ_SLOT( updateGUI() ) );
