@@ -34,7 +34,7 @@ namespace KBibTeX
     */
     class SettingsUserDefinedInput : public TQWidget
     {
-        Q_OBJECT
+        TQ_OBJECT
     public:
         SettingsUserDefinedInput( TQWidget *parent = 0, const char *name = 0 );
         ~SettingsUserDefinedInput();
