@@ -36,7 +36,7 @@ namespace KBibTeX
 {
     class SideBar : public TQWidget
     {
-        Q_OBJECT
+        TQ_OBJECT
     public:
         SideBar( bool isReadOnly, TQWidget *parent = 0, const char *name = 0 );
         ~SideBar();
