@@ -31,7 +31,7 @@ namespace KBibTeX
     */
     class WebQueryDBLPWidget : public WebQueryWidget
     {
-        Q_OBJECT
+        TQ_OBJECT
     public:
         WebQueryDBLPWidget( TQWidget *parent, const char *name = 0 );
         TQCheckBox *checkBoxKeepEntriesSeparate;
@@ -45,7 +45,7 @@ namespace KBibTeX
     */
     class WebQueryDBLP : public WebQuery
     {
-        Q_OBJECT
+        TQ_OBJECT
     public:
         WebQueryDBLP( TQWidget* parent );
         virtual ~WebQueryDBLP();
