@@ -17,9 +17,9 @@
  *   Free Software Foundation, Inc.,                                       *
  *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
  ***************************************************************************/
-#include <ntqfile.h>
-#include <ntqapplication.h>
-#include <ntqspinbox.h>
+#include <tqfile.h>
+#include <tqapplication.h>
+#include <tqspinbox.h>
 
 #include <tdelocale.h>
 #include <klineedit.h>
@@ -28,8 +28,8 @@
 #include <tdeio/netaccess.h>
 #include <kurl.h>
 
-#include <settings.h>
-#include <fileimporterbibtex.h>
+#include "settings.h"
+#include "fileimporterbibtex.h"
 #include "webqueryzmath.h"
 
 namespace KBibTeX
