@@ -28,7 +28,7 @@
 #include "iso5426converter.h"
 #include "iso6937converter.h"
 
-#include <ntqapplication.h>
+#include <tqapplication.h>
 
 #include <config.h>
 
@@ -43,7 +43,7 @@ extern "C"
 
 #include <tdelocale.h>
 
-#include <ntqfile.h>
+#include <tqfile.h>
 
 namespace
 {
